Cowley short range order parameter modifier
###########################################

This repository contains an OVITO modifier that calculates the Cowley short range order parameters from a precomputed bond topology.

With OVITO Pro, you can install this modifier into your OVITO interface with:

``ovitos -m pip install --user git+https://github.com/jwjeffr/cowley_sro_parameters.git``

Or, for use in a standalone Python script:

``pip install --user git+https://github.com/jwjeffr/cowley_sro_parameters.git``

An example of this repository used in a standalone script is in the ``example`` directory.